@@ -182,6 +182,28 @@ def convert_to_list(data):
         return [data]
 
 
+def convert_allocation_pools_to_canonical_format(value):
+    """Convert allocation pools to canonical format.
+
+    :param value: The allocation pools which need to be checked.
+    :returns: Allocation pools with addresses in canonical format.
+    :raises InvalidInput: If the value is not a list of allocation pools.
+    """
+    if value is None:
+        return []
+    try:
+        return [
+            {
+                k: convert_ip_to_canonical_format(v)
+                for k, v in pool.items()
+            }
+            for pool in value
+        ]
+    except Exception as e:
+        raise n_exc.InvalidInput(
+            error_message=_("Invalid data format for allocation pools")) from e
+
+
 def convert_ip_to_canonical_format(value):
     """IP Address is validated and then converted to canonical format.
 
@@ -196,7 +218,12 @@ def convert_ip_to_canonical_format(value):
         ip = netaddr.IPAddress(value)
         if ip.version == constants.IP_VERSION_6:
             return str(ip.format(dialect=netaddr.ipv6_compact))
-    except (netaddr.core.AddrFormatError, ValueError):
+    except Exception:  # nosec B110
+        # netaddr may raise all kinds of exceptions (ValueError,
+        # AttributeError...) if the input is not a valid IP address. Instead of
+        # catching them one by one, just catch all exceptions at once.
+        # Obviously, it would be better if netaddr raised a particular
+        # exception specific to the library. But we don't control it.
         pass
     return value
 
